<?php

namespace App\Http\Controllers\Admin;

use Validator;
use App\Http\Controllers\Controller;
use App\Models\Session;
use App\Models\TVShowVideo;
use Illuminate\Http\Request;
use Exception;

class SessionController extends Controller
{
    public function index()
    {
        try {
            return view('admin.session.index');
        } catch (Exception $e) {
            return response()->json(array('status' => 400, 'errors' => $e->getMessage()));
        }
    }
    public function data(Request $request)
    {
        try {
            if ($request == true) {

                $input_search = $request['input_search'];

                if ($input_search != null && isset($input_search)) {
                    $data = Session::where('name', 'LIKE', "%{$input_search}%")->latest()->get();
                } else {
                    $data = Session::get();
                }

                return DataTables()::of($data)
                    ->addIndexColumn()
                    ->addColumn('action', function ($row) {
                        $btn = '<div class="d-flex justify-content-around">';
                        $btn .= '<a href="' . route("editSession", $row->id) . '" title="Edit"><img src="' . asset("assets/imgs/edit.png") . '" /></a> ';
                        $btn .= '<a href="' . route("deleteSession", $row->id) . '" title="Delete" onclick="return confirm(\'Are you sure !!! You want to Delete this Session ?\')"><img src="' . asset("assets/imgs/trash.png") . '" /></a></div>';
                        return $btn;
                    })
                    ->rawColumns(['action'])
                    ->make(true);
            } else {
                return view('admin.session.index');
            }
        } catch (Exception $e) {
            return response()->json(array('status' => 400, 'errors' => $e->getMessage()));
        }
    }
    public function add()
    {
        try {
            return view('admin.session.add');
        } catch (Exception $e) {
            return response()->json(array('status' => 400, 'errors' => $e->getMessage()));
        }
    }
    public function save(Request $request)
    {
        try {
            $validator = Validator::make($request->all(), [
                'name' => 'required|min:2',
            ]);
            if ($validator->fails()) {
                $errs = $validator->errors()->all();
                return response()->json(array('status' => 400, 'errors' => $errs));
            }

            $session = new Session();
            $session->name = $request->name;

            if ($session->save()) {
                return response()->json(array('status' => 200, 'success' => __('Label.Data Add Successfully')));
            } else {
                return response()->json(array('status' => 400, 'errors' => __('Label.Data Not Add')));
            }
        } catch (Exception $e) {
            return response()->json(array('status' => 400, 'errors' => $e->getMessage()));
        }
    }
    public function edit(Request $request, $id)
    {
        try {
            $session = Session::where('id', $id)->first();
            return view('admin.session.edit', ['result' => $session]);
        } catch (Exception $e) {
            return response()->json(array('status' => 400, 'errors' => $e->getMessage()));
        }
    }
    public function update(Request $request)
    {
        try {
            $validator = Validator::make($request->all(), [
                'name' => 'required|min:2',
            ]);
            if ($validator->fails()) {
                $errs = $validator->errors()->all();
                return response()->json(array('status' => 400, 'errors' => $errs));
            }

            $session = Session::where('id', $request->id)->first();
            if (isset($session->id)) {

                $session->name = $request->name;

                if ($session->save()) {
                    return response()->json(array('status' => 200, 'success' => __('Label.Data Edit Successfully')));
                } else {
                    return response()->json(array('status' => 400, 'errors' => __('Label.Data Not Updated')));
                }
            }
        } catch (Exception $e) {
            return response()->json(array('status' => 400, 'errors' => $e->getMessage()));
        }
    }
    public function delete($id)
    {
        try {

            $session = Session::where('id', $id)->first();
            $TVShowVideo = TVShowVideo::where('session_id', $session->id)->first();
            if ($TVShowVideo) {
                return back()->with('error', "This Session is used on some other table so you can not remove it.");
            } else {
                if ($session->delete()) {
                    return redirect()->route('session')->with('success', __('Label.Data Delete Successfully'));
                }
            }
        } catch (Exception $e) {
            return response()->json(array('status' => 400, 'errors' => $e->getMessage()));
        }
    }
}
